==> blockown-3.0.2-sources.jar: de/pheasn/blockown/database/MySqlDatabase.java <==
package de.pheasn.blockown.database;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.UUID;

import de.pheasn.blockown.BlockOwn;
import de.pheasn.blockown.OwnedBlock;
import de.pheasn.blockown.OwnedEntity;
import de.pheasn.blockown.User;

public class MySqlDatabase extends CachedDatabase {

	private final String DATABASE_URL;

	/**
	 * Instantiates a new MySql database.
	 *
	 * @param plugin
	 *            the plugin
	 * @param host
	 *            the host
	 * @param port
	 *            the port
	 * @param username
	 *            the username
	 * @param password
	 *            the password
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 */
	public MySqlDatabase(BlockOwn plugin, String host, int port, String databaseName, String username, String password) throws SQLException, ClassNotFoundException {
		super(plugin);
		Class.forName("com.mysql.jdbc.Driver");
		DATABASE_URL = "jdbc:mysql://" + host + ":" + port + "/" + databaseName + "?user="
				+ username + "&password=" + password + "&autoReconnect=true";
		connection = connect();
		createTables();
	}

	/**
	 * Instantiates a new MySql database without need for password. Not recommended.
	 *
	 * @param plugin
	 *            the plugin
	 * @param host
	 *            the host
	 * @param port
	 *            the port
	 * @param username
	 *            the username
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 */
	public MySqlDatabase(BlockOwn plugin, String host, int port, String databaseName, String username) throws SQLException, ClassNotFoundException {
		super(plugin);
		Class.forName("com.mysql.jdbc.Driver");
		DATABASE_URL = "jdbc:mysql://" + host + ":" + port + "/" + databaseName + "?user="
				+ username + "&autoReconnect=true";
		connection = connect();
		createTables();
	}

	private Connection connect() throws SQLException {
		return DriverManager.getConnection(DATABASE_URL);
	}

	private void createTables() throws SQLException {
		Statement stmnt = connection.createStatement();
		String query = null;
		query = generateCreateBlockTableQuery();
		stmnt.executeUpdate(query);
		query = generateCreateEntityTableQuery();
		stmnt.executeUpdate(query);
		stmnt.close();
	}

	@Override
	protected String generateCreateBlockTableQuery() {
		StringBuilder query = new StringBuilder(200);
		query.append("CREATE TABLE IF NOT EXISTS ").append(BLOCK_TABLE).append(" (").append(System.lineSeparator())
				.append(WORLD_COLUMN).append(" VARCHAR(50), ").append(System.lineSeparator())
				.append(X_COLUMN).append(" INT, ").append(System.lineSeparator())
				.append(Y_COLUMN).append(" INT, ").append(System.lineSeparator())
				.append(Z_COLUMN).append(" INT, ").append(System.lineSeparator())
				.append(PLAYER_ID_COLUMN).append(" CHAR(36) NOT NULL, ").append(System.lineSeparator())
				.append("PRIMARY KEY (").append(System.lineSeparator())
				.append(WORLD_COLUMN).append(", ").append(System.lineSeparator())
				.append(X_COLUMN).append(", ").append(System.lineSeparator())
				.append(Y_COLUMN).append(", ").append(System.lineSeparator())
				.append(Z_COLUMN).append("));");
		return query.toString();
	}

	@Override
	protected String generateCreateEntityTableQuery() {
		StringBuilder query = new StringBuilder(200);
		query.append("CREATE TABLE IF NOT EXISTS ").append(ENTITY_TABLE).append(" (")
				.append(WORLD_COLUMN).append(" VARCHAR(50) NOT NULL, ")
				.append(ENTITY_ID_COLUMN).append(" CHAR(36), ")
				.append(PLAYER_ID_COLUMN).append(" CHAR(36) NOT NULL, ")
				.append("PRIMARY KEY (").append(ENTITY_ID_COLUMN).append("));");
		return query.toString();
	}

	@Override
	protected String generateGetOwnerQuery(OwnedBlock block) {
		String worldName = block.getWorld().getName();
		StringBuilder query = new StringBuilder(200);
		query.append("SELECT ").append(PLAYER_ID_COLUMN).append(" FROM ").append(BLOCK_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(worldName).append("' AND ")
				.append(X_COLUMN).append("=").append(block.getX()).append(" AND ")
				.append(Y_COLUMN).append("=").append(block.getY()).append(" AND ")
				.append(Z_COLUMN).append("=").append(block.getZ()).append(";");
		return query.toString();
	}

	@Override
	protected String generateGetOwnerQuery(OwnedEntity entity) {
		String worldName = entity.getWorld().getName();
		StringBuilder query = new StringBuilder(200);
		query.append("SELECT ").append(PLAYER_ID_COLUMN).append(" FROM ").append(ENTITY_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(worldName).append("' AND ")
				.append(ENTITY_ID_COLUMN).append("='").append(entity.getUniqueId().toString()).append("';");
		return query.toString();
	}

	@Override
	protected String generateSetBlockOwnerQuery(DatabaseAction databaseAction) {
		OwnedBlock block = (OwnedBlock) databaseAction.getOwnable();
		String worldName = databaseAction.getOwnable().getWorld().getName();
		String playerId = databaseAction.getUser().getId().toString();
		int x = block.getX();
		int y = block.getY();
		int z = block.getZ();
		StringBuilder query = new StringBuilder(300);
		query.append("INSERT INTO ").append(BLOCK_TABLE).append("(")
				.append(WORLD_COLUMN).append(", ").append(X_COLUMN).append(", ")
				.append(Y_COLUMN).append(", ").append(Z_COLUMN).append(", ")
				.append(PLAYER_ID_COLUMN).append(") VALUES('")
				.append(worldName).append("', '").append(x).append("', '")
				.append(y).append("', '").append(z).append("', '").append(playerId).append("')")
				.append(" ON DUPLICATE KEY UPDATE ")
				.append(WORLD_COLUMN).append("=").append("VALUES(").append(WORLD_COLUMN).append("), ")
				.append(X_COLUMN).append("=").append("VALUES(").append(X_COLUMN).append("), ")
				.append(Y_COLUMN).append("=").append("VALUES(").append(Y_COLUMN).append("), ")
				.append(Z_COLUMN).append("=").append("VALUES(").append(Z_COLUMN).append("), ")
				.append(PLAYER_ID_COLUMN).append("=").append("VALUES(").append(PLAYER_ID_COLUMN).append(");");
		return query.toString();
	}

	@Override
	protected String generateSetEntityOwnerQuery(DatabaseAction databaseAction) {
		OwnedEntity entity = (OwnedEntity) databaseAction.getOwnable();
		String worldName = databaseAction.getOwnable().getWorld().getName();
		String playerId = databaseAction.getUser().getId().toString();
		UUID entityId = entity.getUniqueId();
		StringBuilder query = new StringBuilder(300);
		query.append("INSERT INTO ").append(ENTITY_TABLE).append("(")
				.append(WORLD_COLUMN).append(", ").append(ENTITY_ID_COLUMN).append(", ")
				.append(PLAYER_ID_COLUMN).append(") VALUES('")
				.append(worldName).append("', '").append(entityId.toString()).append("', '")
				.append(playerId).append("') ON DUPLICATE UPDATE ")
				.append(WORLD_COLUMN).append("=").append("VALUES(").append(WORLD_COLUMN).append("), ")
				.append(ENTITY_ID_COLUMN).append("=").append("VALUES(").append(ENTITY_ID_COLUMN).append("), ")
				.append(PLAYER_ID_COLUMN).append("=").append("VALUES(").append(PLAYER_ID_COLUMN).append(");");
		return query.toString();
	}

	@Override
	protected String generateDeleteOwnerQuery(OwnedEntity entity) {
		String worldName = entity.getWorld().getName();
		StringBuilder query = new StringBuilder(200);
		query.append("DELETE FROM ").append(ENTITY_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(worldName).append("' AND ")
				.append(ENTITY_ID_COLUMN).append("='").append(entity.getUniqueId().toString()).append("';");
		return query.toString();
	}

	@Override
	protected String generateDeleteOwnerQuery(OwnedBlock block) {
		String worldName = block.getWorld().getName();
		StringBuilder query = new StringBuilder(200);
		query.append("DELETE FROM ").append(BLOCK_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(worldName).append("' AND ")
				.append(X_COLUMN).append("=").append(block.getX()).append(" AND ")
				.append(Y_COLUMN).append("=").append(block.getY()).append(" AND ")
				.append(Z_COLUMN).append("=").append(block.getZ()).append(";");
		return query.toString();
	}

	@Override
	protected String generateDropUserBlocksQuery(User user) {
		StringBuilder query = new StringBuilder(150);
		query.append("DELETE FROM ").append(BLOCK_TABLE).append(" WHERE ")
				.append(PLAYER_ID_COLUMN).append("='").append(user.getId().toString()).append("';");
		return query.toString();
	}

	@Override
	protected String generateDropUserEntitiesQuery(User user) {
		StringBuilder query = new StringBuilder(150);
		query.append("DELETE FROM ").append(ENTITY_TABLE).append(" WHERE ")
				.append(PLAYER_ID_COLUMN).append("='").append(user.getId().toString()).append("';");
		return query.toString();
	}

}

==> blockown-3.0.6-sources.jar: de/pheasn/blockown/database/MySqlDatabase.java <==
package de.pheasn.blockown.database;

import java.io.File;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.UUID;

import de.pheasn.blockown.Output;
import de.pheasn.blockown.OwnedBlock;
import de.pheasn.blockown.OwnedEntity;
import de.pheasn.blockown.User;

public class MySqlDatabase extends CachedDatabase {

	private final String DATABASE_URL;

	/**
	 * Instantiates a new MySql database.
	 *
	 * @param output
	 *            the output
	 * @param host
	 *            the host
	 * @param port
	 *            the port
	 * @param username
	 *            the username
	 * @param password
	 *            the password
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 */
	public MySqlDatabase(Output output, File pluginFolder, String host, int port, String databaseName, String username, String password) throws SQLException, ClassNotFoundException {
		super(output, pluginFolder);
		Class.forName("com.mysql.jdbc.Driver");
		DATABASE_URL = "jdbc:mysql://" + host + ":" + port + "/" + databaseName + "?autoReconnect=true";
		connection = connect(username, password);
		createTables();
	}

	/**
	 * Instantiates a new MySql database without need for password. Not recommended.
	 *
	 * @param output
	 *            the output
	 * @param host
	 *            the host
	 * @param port
	 *            the port
	 * @param username
	 *            the username
	 * @throws SQLException
	 * @throws ClassNotFoundException
	 */
	public MySqlDatabase(Output output, File pluginFolder, String host, int port, String databaseName, String username) throws SQLException, ClassNotFoundException {
		super(output, pluginFolder);
		Class.forName("com.mysql.jdbc.Driver");
		DATABASE_URL = "jdbc:mysql://" + host + ":" + port + "/" + databaseName + "?autoReconnect=true";
		connection = connect(username, null);
		createTables();
	}

	private Connection connect(String user, String password) throws SQLException {
		return DriverManager.getConnection(DATABASE_URL, user, password);
	}

	private void createTables() throws SQLException {
		Statement stmnt = connection.createStatement();
		String query = null;
		query = generateCreateBlockTableQuery();
		stmnt.executeUpdate(query);
		query = generateCreateEntityTableQuery();
		stmnt.executeUpdate(query);
		stmnt.close();
	}

	@Override
	protected String generateCreateBlockTableQuery() {
		StringBuilder query = new StringBuilder(200);
		query.append("CREATE TABLE IF NOT EXISTS ").append(BLOCK_TABLE).append(" (").append(System.lineSeparator())
				.append(WORLD_COLUMN).append(" VARCHAR(50), ").append(System.lineSeparator())
				.append(X_COLUMN).append(" INT, ").append(System.lineSeparator())
				.append(Y_COLUMN).append(" INT, ").append(System.lineSeparator())
				.append(Z_COLUMN).append(" INT, ").append(System.lineSeparator())
				.append(PLAYER_ID_COLUMN).append(" CHAR(36) NOT NULL, ").append(System.lineSeparator())
				.append("PRIMARY KEY (").append(System.lineSeparator())
				.append(WORLD_COLUMN).append(", ").append(System.lineSeparator())
				.append(X_COLUMN).append(", ").append(System.lineSeparator())
				.append(Y_COLUMN).append(", ").append(System.lineSeparator())
				.append(Z_COLUMN).append("));");
		return query.toString();
	}

	@Override
	protected String generateCreateEntityTableQuery() {
		StringBuilder query = new StringBuilder(200);
		query.append("CREATE TABLE IF NOT EXISTS ").append(ENTITY_TABLE).append(" (")
				.append(WORLD_COLUMN).append(" VARCHAR(50) NOT NULL, ")
				.append(ENTITY_ID_COLUMN).append(" CHAR(36), ")
				.append(PLAYER_ID_COLUMN).append(" CHAR(36) NOT NULL, ")
				.append("PRIMARY KEY (").append(ENTITY_ID_COLUMN).append("));");
		return query.toString();
	}

	@Override
	protected String generateGetOwnerQuery(OwnedBlock block) {
		StringBuilder query = new StringBuilder(200);
		query.append("SELECT ").append(PLAYER_ID_COLUMN).append(" FROM ").append(BLOCK_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(block.getWorldName()).append("' AND ")
				.append(X_COLUMN).append("=").append(block.getX()).append(" AND ")
				.append(Y_COLUMN).append("=").append(block.getY()).append(" AND ")
				.append(Z_COLUMN).append("=").append(block.getZ()).append(";");
		return query.toString();
	}

	@Override
	protected String generateGetOwnerQuery(OwnedEntity entity) {
		StringBuilder query = new StringBuilder(200);
		query.append("SELECT ").append(PLAYER_ID_COLUMN).append(" FROM ").append(ENTITY_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(entity.getWorldName()).append("' AND ")
				.append(ENTITY_ID_COLUMN).append("='").append(entity.getUniqueId().toString()).append("';");
		return query.toString();
	}

	@Override
	protected String generateSetBlockOwnerQuery(DatabaseAction databaseAction) {
		OwnedBlock block = (OwnedBlock) databaseAction.getOwnable();
		String worldName = databaseAction.getOwnable().getWorldName();
		String playerId = databaseAction.getUser().getId().toString();
		int x = block.getX();
		int y = block.getY();
		int z = block.getZ();
		StringBuilder query = new StringBuilder(300);
		query.append("INSERT INTO ").append(BLOCK_TABLE).append("(")
				.append(WORLD_COLUMN).append(", ").append(X_COLUMN).append(", ")
				.append(Y_COLUMN).append(", ").append(Z_COLUMN).append(", ")
				.append(PLAYER_ID_COLUMN).append(") VALUES('")
				.append(worldName).append("', '").append(x).append("', '")
				.append(y).append("', '").append(z).append("', '").append(playerId).append("')")
				.append(" ON DUPLICATE KEY UPDATE ")
				.append(WORLD_COLUMN).append("=").append("VALUES(").append(WORLD_COLUMN).append("), ")
				.append(X_COLUMN).append("=").append("VALUES(").append(X_COLUMN).append("), ")
				.append(Y_COLUMN).append("=").append("VALUES(").append(Y_COLUMN).append("), ")
				.append(Z_COLUMN).append("=").append("VALUES(").append(Z_COLUMN).append("), ")
				.append(PLAYER_ID_COLUMN).append("=").append("VALUES(").append(PLAYER_ID_COLUMN).append(");");
		return query.toString();
	}

	@Override
	protected String generateSetEntityOwnerQuery(DatabaseAction databaseAction) {
		OwnedEntity entity = (OwnedEntity) databaseAction.getOwnable();
		String worldName = databaseAction.getOwnable().getWorldName();
		String playerId = databaseAction.getUser().getId().toString();
		UUID entityId = entity.getUniqueId();
		StringBuilder query = new StringBuilder(300);
		query.append("INSERT INTO ").append(ENTITY_TABLE).append("(")
				.append(WORLD_COLUMN).append(", ").append(ENTITY_ID_COLUMN).append(", ")
				.append(PLAYER_ID_COLUMN).append(") VALUES('")
				.append(worldName).append("', '").append(entityId.toString()).append("', '")
				.append(playerId).append("') ON DUPLICATE KEY UPDATE ")
				.append(WORLD_COLUMN).append("=").append("VALUES(").append(WORLD_COLUMN).append("), ")
				.append(ENTITY_ID_COLUMN).append("=").append("VALUES(").append(ENTITY_ID_COLUMN).append("), ")
				.append(PLAYER_ID_COLUMN).append("=").append("VALUES(").append(PLAYER_ID_COLUMN).append(");");
		return query.toString();
	}

	@Override
	protected String generateDeleteOwnerQuery(OwnedEntity entity) {
		String worldName = entity.getWorldName();
		StringBuilder query = new StringBuilder(200);
		query.append("DELETE FROM ").append(ENTITY_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(worldName).append("' AND ")
				.append(ENTITY_ID_COLUMN).append("='").append(entity.getUniqueId().toString()).append("';");
		return query.toString();
	}

	@Override
	protected String generateDeleteOwnerQuery(OwnedBlock block) {
		String worldName = block.getWorldName();
		StringBuilder query = new StringBuilder(200);
		query.append("DELETE FROM ").append(BLOCK_TABLE).append(" WHERE ")
				.append(WORLD_COLUMN).append("='").append(worldName).append("' AND ")
				.append(X_COLUMN).append("=").append(block.getX()).append(" AND ")
				.append(Y_COLUMN).append("=").append(block.getY()).append(" AND ")
				.append(Z_COLUMN).append("=").append(block.getZ()).append(";");
		return query.toString();
	}

	@Override
	protected String generateDropUserBlocksQuery(User user) {
		StringBuilder query = new StringBuilder(150);
		query.append("DELETE FROM ").append(BLOCK_TABLE).append(" WHERE ")
				.append(PLAYER_ID_COLUMN).append("='").append(user.getId().toString()).append("';");
		return query.toString();
	}

	@Override
	protected String generateDropUserEntitiesQuery(User user) {
		StringBuilder query = new StringBuilder(150);
		query.append("DELETE FROM ").append(ENTITY_TABLE).append(" WHERE ")
				.append(PLAYER_ID_COLUMN).append("='").append(user.getId().toString()).append("';");
		return query.toString();
	}

}
